@@ -1,14 +1,14 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2022, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
-require_relative 'output/bar'
-require_relative 'output/text'
-require_relative 'output/xterm'
+require_relative "output/bar"
+require_relative "output/text"
+require_relative "output/xterm"
 
-require_relative 'output/null'
-require_relative 'output/progress'
+require_relative "output/null"
+require_relative "output/progress"
 
 module Sus
 	module Output
@@ -39,8 +39,9 @@ module Sus
 			
 			output[:passed] = output.style(:green)
 			output[:failed] = output.style(:red)
-			output[:error] = output.style(:red)
-			output[:skip] = output.style(:blue)
+			output[:deferred] = output.style(:yellow)
+			output[:skipped] = output.style(:blue)
+			output[:errored] = output.style(:red)
 			# output[:inform] = output.style(nil, nil, :bold)
 			
 			return output
